var app = angular.module('makemydayApp.controllers', []);

app.controller('WelcomeController', function($scope, $state, $ionicPopup, $cordovaFacebook) {
	$scope.data = {};
	$scope.login = function() {
        $state.go('login');
    };

    $scope.register = function() {
        $state.go('register');
    };
    
    
    var fbLogged = new Parse.Promise();

    var fbLoginSuccess = function(response) {
        if (!response.authResponse){
            fbLoginError("No existeix el authResponse");
            return;
        }
        var expDate = new Date(
            new Date().getTime() + response.authResponse.expiresIn * 1000
        ).toISOString();

        var authData = {
            id: String(response.authResponse.userID),
            access_token: response.authResponse.accessToken,
            expiration_date: expDate
        }
        fbLogged.resolve(authData);
        fbLoginSuccess = null;
        console.log(response);
    };

    var fbLoginError = function(error){
        fbLogged.reject(error);
    };

    $scope.loginFacebook = function(){
        console.log('LoginFB');
        facebookConnectPlugin.login(['email'], fbLoginSuccess, fbLoginError);

        fbLogged.then( function(authData) {
        	console.log("Entrant "+JSON.stringify(authData));
            return Parse.FacebookUtils.logIn(authData);
        })
        .then( function(userObject) {
            var authData = userObject.get('authData');
            console.log("Entrant userObject"+JSON.stringify(userObject));
  	        var fbValues = "?fields=id,name,email";
            facebookConnectPlugin.api("/me"+fbValues,null,
                function(response) {
	            	console.log("Entrant response"+JSON.stringify(response));
	            	var user = Parse.User.current();
	            	user.set("username", response.name);
	            	user.set("email", response.email);
	            	user.set("idFB", response.id);
	            	user.save();	            	
                },
                function(error) {
                    console.log(error);
                }
            );
            $state.go('menu.home');
        }, function(error) {
            console.log(error);
        });
    };
});

app.controller('RegisterController', function($scope, $state, $ionicPopup) {
	$scope.data = {};
	$scope.signup = function(){
	  //Create a new user on Parse
	  var user = new Parse.User();
	  user.set("username", $scope.data.username);
	  user.set("password", $scope.data.password);
	  user.set("email", $scope.data.email);

	  var birthString = $scope.data.birthdate;
	  var birthdate = new Date (birthString);

	  if (typeof birthdate != 'undefined'){
	  	 //Limita la data de naixement a 14 anys
	      var dateDiff = Date.now() - birthdate.getTime();	
	      var years = Math.round(dateDiff/(24*60*60*1000*365));
	      if (years<14){
	    	  $ionicPopup.alert({
                title: 'El registre ha fallat',
                template: 'Has de ser major de 14 anys per registrarte a l\'aplicació'
              });
	    	  return;
	      }
	  }
	  user.set("birthdate", birthString);
      
	  user.signUp(null, {
	    success: function(user) {
	    	if (user.get("emailVerified")==true){
	    		$state.go('menu.home');
	    	}
	    	else{
	    		$state.go('login');
	    		$ionicPopup.alert({
	                title: 'Verificaci&oacute; del email',
	                template: 'Has de verificar el teu email per entrar a l\'aplicaci&oacute;'
	              });
	    	}
	    },
	    error: function(user, error) {
	    	$ionicPopup.alert({
                title: 'El registre ha fallat',
                template: 'El nom d\'usuari o email ja existeixen'
              });
	    }
	  });
	};
});

app.controller('LoginController', function($scope, $state, $ionicPopup) {
	$scope.data = {};
	$scope.login = function(){
	  Parse.User.logIn($scope.data.username, $scope.data.password, {
	    success: function(user) {
	    	if (user.get("emailVerified")==true){
	    		$state.go('menu.home');
	    	}
	    	else{
	    		$state.go('login');
	    		$ionicPopup.alert({
	                title: 'Verificaci&oacute; del email',
	                template: 'Has de verificar el teu email per entrar a l\'aplicaci&oacute;'
	              });
	    	}
	    },
	    error: function(user, error) {
	      // The login failed. Check error to see why.
	    	$ionicPopup.alert({
                title: 'El login ha fallat',
                template: 'Si us plau comprova el teu nom d\'usuari o password'
              });
	    }
	  });
  };
});

app.controller('PasswordResetController', function($scope, $state, $ionicPopup) {
	$scope.data = {};
	$scope.reset = function(){
		Parse.User.requestPasswordReset($scope.data.email, {
	    success: function() {
			$ionicPopup.alert({
	            template: 'S\'ha enviat un email per canviar la contrasenya'
	          });
	    },
	    error: function(user, error) {
	    	$ionicPopup.alert({
                template: 'No s\'ha trobat el email'
              });
	    }
	  });
  };
});

app.controller('MenuController', function($scope, $state) {
	$scope.data = {};
	var user = Parse.User.current();
	$scope.data.name = user.get("username");

});

app.controller('HomeController', function($scope, $state, $ionicPopup) {
	$scope.data = {};
	var user = Parse.User.current();
	$scope.data.picture=user.get("picture");
	$scope.data.idFB=user.get("idFB");
	$scope.data.name = user.get("username");
	$scope.saveDiary = function(){
		var diary = new Parse.Object("Diary");
		diary.save({
			state: $scope.data.state,
			comments: $scope.data.comments,
			user: user
			}, {
				success: function() {
					$ionicPopup.alert({
		                title: 'Diari',
		                template: 'Entrada de diari publicada'
		              });
					$scope.data.comments ="";
					$scope.data.state.isChecked = false;
				},
				error: function(error) {
					$ionicPopup.alert({
		                title: 'Diari',
		                template: 'No s\'ha pogut publicar el diari '
		              });
				}
			});
	};
});

app.controller('AccountController', function($scope, $state, $ionicPopup) {
	$scope.data = {};
	var user = Parse.User.current();
	if (typeof user != 'undefined'){
		$scope.data.email = user.get("email");
		$scope.data.birthdate = user.get("birthdate");
	}

	$scope.saveUser = function(){
		user.set("email", $scope.data.email);
		user.set("birthdate", $scope.data.birthdate);
		var password1 = $scope.data.password1;
		var password2 = $scope.data.password2;
		if (password1!="" && password2!=""){
			if (password1==password2){
				user.set("password",password1);
			}
			else{
				$ionicPopup.alert({
	                title: 'El meu compte',
	                template: 'Les noves contrasenyes no coincideixen'
	              });
				return;
			}
		}
		
		user.save({
		    success: function() {
		    	$ionicPopup.alert({
	                title: 'El meu compte',
	                template: 'El compte d\'usuari s\'ha guardat correctament'
	              });
		    },
		    error: function(error) {
		    	$ionicPopup.alert({
	                title: 'Error',
	                template: error.message
	              });
		    }
		});
	};
});

app.controller('MyProfileController', function($scope, $state, $ionicPopup, $ionicActionSheet, $cordovaCamera, $ionicLoading, MyProfileService) {
	$scope.data = {};
	var user = Parse.User.current();
	if (typeof user != 'undefined'){
		$scope.data.nick = user.get("nick");
		$scope.data.state = user.get("state");
		$scope.data.description = user.get("description");
		$scope.data.lookfor = user.get("lookfor");
		$scope.data.tag1 = user.get("tag1");
		$scope.data.tag2 = user.get("tag2");
		$scope.data.tag3 = user.get("tag3");
		$scope.data.picture = user.get("picture");
		$scope.data.idFB = user.get("idFB");
	}
	
	$scope.saveMyProfile = function(){	
		$ionicLoading.show();
		MyProfileService.saveMyProfile($scope.data);
		$ionicLoading.hide();
	};
	
	$scope.addPicture = function() {
	    $scope.hideSheet = $ionicActionSheet.show({
	      buttons: [
	        { text: 'Camara' },
	        { text: 'Galeria' }
	      ],
	      titleText: 'Inclou una imatge',
	      cancelText: 'Cancel·la',
	      buttonClicked: function(index) {
	        $scope.addPicture2(index);
	      }
	    });
	  };
	 
	  $scope.addPicture2 = function(type) {
	    $scope.hideSheet();
	    var options = {};
	    if (type==0){
	    	options = {
	    		quality:50,
	    		destinationType : Camera.DestinationType.DATA_URL,
	    		sourceType: Camera.PictureSourceType.CAMERA,
	    		allowEdit:true,
	    		encodingType:Camera.EncodingType.JPEG,
	    		targetWidth:480,
	    		popoverOptions:CameraPopoverOptions,
	    		saveToPhotoAlbum:false
	    	};
	    }
	    else{
	    	options = {
	    		quality:50,
	    		destinationType : Camera.DestinationType.DATA_URL,
	    		sourceType: Camera.PictureSourceType.PHOTOLIBRARY,
	    		allowEdit:true,
	    		encodingType:Camera.EncodingType.JPEG,
	    		targetWidth:480,
	    		popoverOptions:CameraPopoverOptions,
	    		saveToPhotoAlbum:false
	    	};
	    }
	    $cordovaCamera.getPicture(options).then(function(imageData){
	    	$scope.data.picture=imageData;
	    },function(error){
	    	$ionicPopup.alert({
                title: 'Error',
                template: 'Ha hagut un problema capturant la imatge, si us plau prova-ho de nou.'
              });
	    });
	  };
});

app.controller('SearchController', function($scope, $state, $ionicPopup) {
	$scope.data = {};
	var userIdCurrent = Parse.User.current().id;
	
	$scope.chat = function(user){
	}; 	
	
	$scope.search = function(){
		
		var query = new Parse.Query("_User");
		var tagsSearch = $scope.data.tags;
		if (typeof tagsSearch!='undefined'){
			var query2 = new Parse.Query("_User");
			query2.contains("tag1",tagsSearch);
			
			var query3 = new Parse.Query("_User");
			query3.contains("tag2",tagsSearch);
			
			var query4 = new Parse.Query("_User");
			query4.contains("tag3",tagsSearch);

			query = Parse.Query.or(query2,query3,query4);
		}
		
		var nickSearch = $scope.data.nick;
		if (typeof nickSearch!='undefined'){
			query.contains("nick",nickSearch);
		}
		
		var descriptionSearch = $scope.data.description;
		if (typeof descriptionSearch!='undefined'){
			query.contains("description",descriptionSearch);
		}
		
		query.find({
		   success: function(items) {
		     var userList = {};

		     for (var i = 0; i < items.length; i++) {
		       var object = items[i];
		       if (object.id!=userIdCurrent){
		    	   var age=0;
		    	   if (typeof object.get('birthdate')!='undefined'){
		    		   var ageDifMs = Date.now() - object.get('birthdate').getTime();
		    		   var ageDate = new Date(ageDifMs); // miliseconds from epoch
		    		   age = Math.abs(ageDate.getUTCFullYear() - 1970);
		    	   }
		    	   userList[i] = {'id':object.id,'nick':object.get('nick'),'age':age,'state':object.get('state'),'tag1':'#'+object.get('tag1'),'tag2':'#'+object.get('tag2'),'tag3':'#'+object.get('tag3'),'idFB':object.get('idFB'),'picture':object.get('picture')};
		       }
		     }
		     $scope.userList = userList;
		     $state.go('menu.search');
		   },
		   error: function(error) {
			   $ionicPopup.alert({
	                title: 'Error',
	                template: error.message
	              });
		   }
		});
  };
});

app.controller('ProfileUserController', function($scope, $state, $stateParams, $ionicPopup,$rootScope,$filter,$window) {
	$scope.data = {};
	var User = Parse.Object.extend("_User");
	var query = new Parse.Query(User);
	var userObj = {};
	//query.include("user");
	query.get($stateParams.id, {
        success: function(object) {
        	var age=0;
        	if (typeof object.get('birthdate')!='undefined'){
		       var ageDifMs = Date.now() - object.get('birthdate').getTime();
		       var ageDate = new Date(ageDifMs); // miliseconds from epoch
		       age = Math.abs(ageDate.getUTCFullYear() - 1970);
	        }
        	userObj = {'id':object.id,'nick':object.get('nick'),'age':age,'state':object.get('state'),'tag1':'#'+object.get('tag1'),'tag2':'#'+object.get('tag2'),'tag3':'#'+object.get('tag3'),'description':object.get('description'),'lookfor':object.get('lookfor'),'idFB':object.get('idFB'),'picture':object.get('picture')};
        	$rootScope.user = userObj;

        },
        error: function(error) {
            console.log("An error occured :(");
        }
    });
	
	$scope.chat = function(){
		$ionicPopup.alert({
            title: 'Chat',
            template: "A instal·lar en noves versions"
          });
	}; 
   
	$scope.addFav = function(userId){
		var User = Parse.Object.extend("_User");
		var query = new Parse.Query(User);
		var Favs = Parse.Object.extend("Favs");
		var query2 = new Parse.Query(Favs);
		var fav;
		var user = Parse.User.current();
		
		query.get(userId)
        .then(function (faved) {
			query2.equalTo("user",user);
			query2.equalTo("faved",faved);
			query2.first({
			    success: function(result) {
			    	fav = result;
			        if (typeof fav == 'undefined'){
			        	var favs = new Parse.Object("Favs");
				        favs.set("user", user);
				        favs.set("faved", faved);
				        favs.save({
						    success: function() {
						    	$ionicPopup.alert({
						              title: 'Favorits',
						              template: "Inclòs als favorits"
						            });
						    },
						    error: function(error) {
						    	$ionicPopup.alert({
					                title: 'Error',
					                template: error.message
					              });
						    }
						});
			        }
			    },
			    error: function(error) {
					$ionicPopup.alert({
		                title: 'Error',
		                template: error.message
		              });
			    }
			});
        });
	  };
	
	$scope.showDiary = function(userId){
		var User = Parse.Object.extend("_User");
		var query = new Parse.Query(User);
		query.get(userId)
        .then(function (user) {
        	var Diary = Parse.Object.extend("Diary");
    		var query2 = new Parse.Query(Diary);
        	query2.equalTo("user",user);
        	query2.find({
        	    success: function(items) {
        	    	var diaryList = {};
	       		    for (var i = 0; i < items.length; i++) {
	       		       var object = items[i];
	       		       var formatDate = $filter('date')(object.get('createdAt'), "dd/MM/yyyy hh:mm");
	       		       diaryList[i] = {'state':object.get('state'),'comments':object.get('comments'),'date':formatDate};
	       		    }
	       		    $rootScope.diaryList = diaryList;
	       		    $state.go('menu.diaries', {}, {reload: true});
        	    },
        	    error: function(error) {
        			$ionicPopup.alert({
                        title: 'Error',
                        template: error.message
                      });
        	    }
        	});
          });
	};

});

app.controller('FavsController', function($scope, $state) {
	$scope.data = {};
	var User = Parse.Object.extend("Favs");
	var query = new Parse.Query(User);

	var user = Parse.User.current();
	
	query.equalTo("user",user);
	query.include("faved");
	query.find({
		   success: function(items) {
		     var userList = {};
		     for (var i = 0; i < items.length; i++) {
		       var userObj = items[i];
		       var object = userObj.get('faved');
	    	   var age=0;
	    	   if (typeof object.get('birthdate')!='undefined'){
	    		   var ageDifMs = Date.now() - object.get('birthdate').getTime();
	    		   var ageDate = new Date(ageDifMs); // miliseconds from epoch
	    		   age = Math.abs(ageDate.getUTCFullYear() - 1970);
	    	   }
	    	   userList[i] = {'id':object.id,'nick':object.get('nick'),'age':age,'state':object.get('state'),'tag1':'#'+object.get('tag1'),'tag2':'#'+object.get('tag2'),'tag3':'#'+object.get('tag3'),'idFB':object.get('idFB'),'picture':object.get('picture')};
		     }
		     $scope.userList = userList;
		     $state.go('menu.favs');
		   },
		   error: function(error) {
			   $ionicPopup.alert({
	                title: 'Error',
	                template: error.message
	              });
		   }
		});
});


app.controller('DiaryController', function($scope, $state) {
	$scope.data = {};
	
	$scope.myGoBack = function() {
	    $ionicHistory.goBack();
	};
});

app.controller('TagsController', function($scope, $state) {

	$state.go('menu.tags');
});

app.controller('TagDetailController', function($scope, $state, $stateParams, $ionicPopup,$rootScope,$filter,$window) {
	$scope.data = {};
	var userIdCurrent = Parse.User.current().id;
	
	var User = Parse.Object.extend("_User");
	var queryA = new Parse.Query(User);
	var queryB = new Parse.Query(User);
	var queryC = new Parse.Query(User);
	var query;
	var query1;
	var query2;
	var query3;
	var tagsSearch1;
	var tagsSearch2;
	var tagsSearch3;

	var userObj = {};
	var type = $stateParams.type;

	if (type==1){
		tagsSearch1="depress";
		tagsSearch2="trist";
		tagsSearch3="suicidi";
	}
	else if (type==2){
		tagsSearch1="maltracta";
		tagsSearch2="viol";
		tagsSearch3="genere";
	}
	else if (type==3){
		tagsSearch1="bully";
		tagsSearch2="acos";
		tagsSearch3="maltracta";
	}
	else if (type==4){
		tagsSearch1="anorexia";
		tagsSearch2="bulímia";
		tagsSearch3="aliment";
	}
	else if (type==5){
		tagsSearch1="droga";
		tagsSearch2="addicció";
		tagsSearch3="alcohol";
	}
	
	if (typeof tagsSearch1!='undefined'){
		query1 = new Parse.Query("_User");
		query1.contains("tag1",tagsSearch1);
		
		query2 = new Parse.Query("_User");
		query2.contains("tag2",tagsSearch1);
		
		query3 = new Parse.Query("_User");
		query3.contains("tag3",tagsSearch1);

		queryA = Parse.Query.or(query1,query2,query3);
	}
	if (typeof tagsSearch2!='undefined'){
		query1 = new Parse.Query("_User");
		query1.contains("tag1",tagsSearch2);
		
		query2 = new Parse.Query("_User");
		query2.contains("tag2",tagsSearch2);
		
		query3 = new Parse.Query("_User");
		query3.contains("tag3",tagsSearch2);

		queryB = Parse.Query.or(query1,query2,query3);
	}
	if (typeof tagsSearch3!='undefined'){
		query1 = new Parse.Query("_User");
		query1.contains("tag1",tagsSearch3);
		
		query2 = new Parse.Query("_User");
		query2.contains("tag2",tagsSearch3);
		
		query3 = new Parse.Query("_User");
		query3.contains("tag3",tagsSearch3);

		queryC = Parse.Query.or(query1,query2,query3);
	}
	
	query = Parse.Query.or(queryA,queryB,queryC);
	query.find({
        success: function(items) {
        	var userList = {};

		     for (var i = 0; i < items.length; i++) {
		       var object = items[i];
		       if (object.id!=userIdCurrent){
		    	   var age=0;
		    	   if (typeof object.get('birthdate')!='undefined'){
		    		   var ageDifMs = Date.now() - object.get('birthdate').getTime();
		    		   var ageDate = new Date(ageDifMs); // miliseconds from epoch
		    		   age = Math.abs(ageDate.getUTCFullYear() - 1970);
		    	   }
		    	   userList[i] = {'id':object.id,'nick':object.get('nick'),'age':age,'state':object.get('state'),'tag1':'#'+object.get('tag1'),'tag2':'#'+object.get('tag2'),'tag3':'#'+object.get('tag3'),'idFB':object.get('idFB'),'picture':object.get('picture')};
		       }
		     }
		     $scope.userList = userList;
		     $state.go('menu.tagDetail');
        },
        error: function(error) {
            console.log("An error occured :(");
        }
    });
});

app.controller('LogoutController', function($scope, $state) {
	$scope.data = {};
	Parse.User.logOut();
	$state.go('welcome', {}, {reload:true});
});

app.directive('backImg', function(){
    return function(scope, element, attrs){
        var url = attrs.backImg;
        var content = element.find('a');
        content.css({
            'background': 'url(' + url +')',
            'height':'100%',
            'width': '100%'
        });
    };
});